@@ -263,7 +263,7 @@ Net::SAML2::SP
 
 =head1 VERSION
 
-version 0.34
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -397,19 +397,11 @@ Returns the metadata XML document for this SP.
 
 =head1 AUTHOR
 
-Original Author: Chris Andrews  <chrisa@cpan.org>
+Chris Andrews  <chrisa@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Chris Andrews and Others; in detail:
-
-  Copyright 2010-2011  Chris Andrews
-            2012       Peter Marschall
-            2017       Alessandro Ranellucci
-            2019       Timothy Legge
-            2020       Timothy Legge, Wesley Schwengle
-            2021       Timothy Legge
-
+This software is copyright (c) 2021 by Chris Andrews and Others, see the git log.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
